summaryrefslogtreecommitdiffhomepage
path: root/packages/wire/src/index.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/wire/src/index.ts')
-rw-r--r--packages/wire/src/index.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/wire/src/index.ts b/packages/wire/src/index.ts
index 8c85f89..4ab8825 100644
--- a/packages/wire/src/index.ts
+++ b/packages/wire/src/index.ts
@@ -535,12 +535,12 @@ export interface ConversationMeta {
* Result of a compaction operation. `summary` is the text the model produced;
* `messagesKept` is how many recent messages were retained after the summary;
* `messagesSummarized` is how many old messages were replaced by the summary.
* `archiveId` is the ID of the new conversation that holds the full
* pre-compaction history (non-destructive — the original history is preserved).
*/
export interface CompactionResult {
readonly summary: string;
- readonly archiveId: string;
+ readonly newConversationId: string;
readonly messagesSummarized: number;
readonly messagesKept: number;
}
@@ -535,12 +535,12 @@ export interface ConversationMeta {
* `messagesKept` is how many recent messages were retained after the summary;
* `messagesSummarized` is how many old messages were replaced by the summary.
- * `archiveId` is the ID of the new conversation that holds the full
+ * `newConversationId` is the ID of the new conversation that holds the full
* pre-compaction history (non-destructive — the original history is preserved).
*/